require 'spec_helper'

module TCellAgent
  describe Configuration do
    describe 'should_instrument?' do
      context 'with the agent disabled' do
        it 'should return false' do
          config = Configuration.new
          config.enabled = false

          expect(config.should_instrument?).to be_falsey
        end
      end
      context 'with the agent enabled' do
        context 'with all instrumentation enabled' do
          context 'with no parameters' do
            it 'should return true' do
              config = Configuration.new
              config.enabled = true
              config.instrument = true

              expect(config.should_instrument?).to be_truthy
            end
          end
          context 'with parameters' do
            it 'should return true' do
              config = Configuration.new
              config.enabled = true
              config.instrument = true
              config.disabled_instrumentation = Set.new

              expect(config.should_instrument?('devise')).to be_truthy
            end
          end
        end
        context 'with auth frameworks disabled' do
          it 'should return false' do
            config = Configuration.new
            config.disabled_instrumentation = Set.new(%w[authlogic devise doorkeeper])

            expect(config.should_instrument?('devise')).to be_falsey
          end
        end
      end
    end
    describe 'populate_configuration' do
      context 'with a poor native_agent_config_response' do
        it 'should not throw an error' do
          native_agent_config_response = {}

          config = Configuration.new
          expect do
            config.populate_configuration(native_agent_config_response)
          end.not_to raise_error
        end
      end
      context 'with an elaborate native_agent_config_response' do
        it 'should set all the correct configurations' do
          native_agent_config_response = { 'enabled' => true,
                                           'disabled_instrumentation' => %w[devise doorkeeper],
                                           'update_policy' => 'true',
                                           'applications' => { 'first' => { 'app_id' => 'app_id_placeholder',
                                                                            'api_key' => 'api_key_paceholder',
                                                                            'hmac_key' => 'hmac_key_placeholder',
                                                                            'password_hmac_key' => 'password_hmac_key_placeholder',
                                                                            'proxy_config' => { 'reverse_proxy' => true,
                                                                                                'reverse_proxy_ip_address_header' => 'X-Forwarded-For' } } },
                                           'endpoint_config' => { 'api_url' => 'https://us.agent.tcell.insight.rapid7.com/api/v1' },
                                           'ruby_config' => { 'enable_policy_polling' => true } }

          config = Configuration.new
          config.populate_configuration(native_agent_config_response)

          expect(config.disabled_instrumentation).to be_a(Set)
          expect(config.disabled_instrumentation).to include('devise', 'doorkeeper')
          expect(config.enable_intercept_requests).to be_truthy
        end
      end
    end
  end
end
