# frozen_string_literal: true

def test_rails
  expect(Rails::Server.instance_methods.include?(:tcell_build_app)).to be_truthy
end

def test_thin
  expect(Thin::Server.instance_methods.include?(:original_start)).to be_truthy
end

def test_unicorn
  expect(Unicorn::HttpServer::START_CTX[0]).to be_falsy
  expect(Unicorn::HttpServer.instance_methods.include?(:tcell_init_worker_process)).to be_truthy
  expect(Unicorn::HttpServer.instance_methods.include?(:tcell_load_config!)).to be_truthy
end

def test_passenger
  expect(PhusionPassenger::LoaderSharedHelpers.instance_methods.include?(:tcell_before_handling_requests))
end

def test_puma
  expect(Puma.cli_config.options[:preload_app]).to be_falsey
  expect(Puma::Server.instance_methods.include?(:tcell_original_run)).to be_truthy
end

def test_server(filenames, funcs)
  fork do
    filenames.each do |file|
      load file
    end

    load 'tcell_agent/instrument_servers.rb'

    funcs.each do |func|
      method(func).call
    end
  end
end

describe 'instrument_servers' do
  context 'with single server dependency' do
    context 'with webrick server' do
      it 'should instrument Webrick' do
        mocks = ['spec/support/server_mocks/rails_mock.rb']
        tests = [:test_rails]
        test_server(mocks, tests)
      end
    end

    context 'with Thin server' do
      it 'should instrument Thin' do
        mocks = ['spec/support/server_mocks/thin_mock.rb']
        tests = [:test_thin]
        test_server(mocks, tests)
      end
    end

    context 'with Puma server' do
      it 'should instrument Puma' do
        mocks = ['spec/support/server_mocks/puma_mock.rb']
        tests = [:test_puma]
        test_server(mocks, tests)
      end
    end

    context 'with Unicorn server' do
      it 'should instrument Unicorn' do
        mocks = ['spec/support/server_mocks/unicorn_mock.rb']
        tests = [:test_unicorn]
        test_server(mocks, tests)
      end
    end

    context 'with Passenger server' do
      it 'should instrument Unicorn' do
        mocks = ['spec/support/server_mocks/passenger_mock.rb']
        tests = [:test_passenger]
        test_server(mocks, tests)
      end
    end
  end
  context 'with multiple server dependencies' do
    it 'should instrument all servers available' do
      mocks = ['spec/support/server_mocks/rails_mock.rb',
               'spec/support/server_mocks/thin_mock.rb',
               'spec/support/server_mocks/puma_mock.rb',
               'spec/support/server_mocks/unicorn_mock.rb',
               'spec/support/server_mocks/passenger_mock.rb']

      tests = %i[test_rails test_thin test_puma test_unicorn test_passenger]

      test_server(mocks, tests)
    end
  end
end
