require 'spec_helper'

module TCellAgent
  module Policies
    describe HeadersPolicy do
      describe '#get_headers' do
        context 'with enabled policy' do
          before(:each) do
            configuration = TCellAgent::Tests::ConfigurationBuilder.new.build
            @native_agent = TCellAgent::Rust::NativeAgent.create_agent(
              configuration
            )
            @tcell_context = TCellAgent::Tests::TCellContextBuilder.new.update_attribute(
              'session_id', 'session-id'
            ).update_attribute(
              'route_id', 'route-id'
            ).build
          end

          after(:each) do
            TCellAgent::Rust::NativeAgent.free_agent(@native_agent.agent_ptr)
          end

          it 'should return csp header' do
            enablements = @native_agent.update_policies(
              {
                'clickjacking' => {
                  'version' => 1,
                  'policy_id' => 'xyzd',
                  'headers' => [
                    {
                      'name' => 'Content-Security-Policy',
                      'value' => "frame-ancestors 'none'",
                      'report_uri' => 'https://input.tcell-preview.io/csp/430d'
                    }
                  ]
                }
              }
            )['enablements']
            expect(enablements['headers']).to eq(true)

            @policy = HeadersPolicy.new(@native_agent, enablements)
            expect(@policy.enabled).to eq(true)

            expect(
              @policy.get_headers('text/html', @tcell_context)
            ).to eq(
              [{ 'name' => 'Content-Security-Policy',
                 'value' => "frame-ancestors 'none'; report-uri https://input.tcell-preview.io/csp/430d?sid=ab7074d0bf86c2884766d88b6ad9de4a&rid=route-id" }]
            )
          end
        end
      end
    end
  end
end
