require 'spec_helper'

module TCellAgent
  module Policies
    describe JsAgentPolicy do
      describe '#initialize' do
        context 'empty enablements' do
          it 'should disable the policy' do
            native_agent = double('native_agent')
            policy = JsAgentPolicy.new(native_agent, {})
            expect(policy.enabled).to eq(false)
          end
        end
      end

      describe '#check_redirect' do
        context 'with disabled policy' do
          it 'should not call the native library' do
            native_agent = double('native_agent')
            policy = JsAgentPolicy.new(native_agent, {})

            expect(native_agent).to_not receive(:get_js_agent_script_tag)

            tcell_context = double('tcell_context')
            expect(
              policy.get_js_agent_script_tag(tcell_context)
            ).to eq(nil)
          end
        end

        context 'with native agent' do
          before(:each) do
            configuration = TCellAgent::Tests::ConfigurationBuilder.new.build
            @native_agent = TCellAgent::Rust::NativeAgent.create_agent(
              configuration
            )
          end

          after(:each) do
            TCellAgent::Rust::NativeAgent.free_agent(@native_agent.agent_ptr)
          end

          context 'enabled js agent policy' do
            it 'should return js agent script tag' do
              enablements = @native_agent.update_policies(
                {
                  'jsagentinjection' => {
                    'enabled' => true,
                    'api_key' => 'AQABBA',
                    'excludes' => [],
                    'policy_id' => 'jsagentinjection-v1-1',
                    'version' => 1
                  }
                }
              )['enablements']
              expect(enablements['jsagentinjection']).to eq(true)

              @policy = JsAgentPolicy.new(@native_agent, enablements)
              expect(@policy.enabled).to eq(true)

              tcell_context = TCellAgent::Tests::TCellContextBuilder.new.build
              expect(
                @policy.get_js_agent_script_tag(tcell_context)
              ).to eq(
                '<script src="https://jsagent.tcell.io/tcellagent.min.js" ' \
                'tcellappid="TestAppId-AppId" tcellapikey="AQABBA" ' \
                'tcellbaseurl="https://api.tcell-preview.io/agents/api/v1"></script>'
              )
            end
          end
        end
      end
    end
  end
end
