require 'spec_helper'

module TCellAgent
  describe PoliciesManager do
    before(:all) do
      assert_policy_state = proc do |policies, state|
        expect(policies.keys.size).to eq(10)

        policies.each_value do |policy|
          next if policy.instance_of?(TCellAgent::Policies::LoginPolicy)
          next if policy.instance_of?(TCellAgent::Policies::SystemEnablements)

          expect(policy.enabled).to eq(state)
        end

        expect(
          policies[
            TCellAgent::Policies::LoginPolicy.api_identifier
          ].login_success_enabled
        ).to eq(state)
        expect(
          policies[
            TCellAgent::Policies::LoginPolicy.api_identifier
          ].login_failed_enabled
        ).to eq(state)
      end

      @assert_all_policies_enabled = proc do |policies|
        assert_policy_state.call(policies, true)
      end
      @assert_all_policies_disabled = proc do |policies|
        assert_policy_state.call(policies, false)
      end
    end

    describe '#initialize' do
      context 'default PoliciesManager' do
        it 'should have all policies disabled' do
          native_agent = double('native_agent')
          policies_manager = PoliciesManager.new(native_agent)

          @assert_all_policies_disabled.call(policies_manager.policies)
        end
      end

      describe '#process_policy_json' do
        before(:each) do
          @native_agent = double('native_agent')
          @policies_manager = PoliciesManager.new(@native_agent)
        end

        context 'nil enablements' do
          it 'all policies should remain disabled' do
            @policies_manager.process_policy_json(nil, {})
            @assert_all_policies_disabled.call(@policies_manager.policies)
          end
        end

        context 'empty enablements' do
          it 'all policies should remain disabled' do
            @policies_manager.process_policy_json({}, {})
            @assert_all_policies_disabled.call(@policies_manager.policies)
          end
        end

        context 'empty enablements' do
          it 'all policies should remain disabled' do
            @policies_manager.process_policy_json({}, {})
            @assert_all_policies_disabled.call(@policies_manager.policies)
          end
        end

        context 'with enablements and policies_json' do
          it 'all policies should be enabled' do
            enablements = {
              'appfirewall' => true,
              'cmdi' => true,
              'headers' => true,
              'http_redirect' => true,
              'jsagentinjection' => true,
              'patches' => true,
              'local_file_access' => true,
              'login_success_enabled' => true,
              'login_failed_enabled' => true
            }
            policies_json = {
              'dlp' => {
                'policy_id' => 'policy-id',
                'version' => 1,
                'data' => {
                  'data_discovery' => {
                    'database_enabled' => true
                  }
                }
              }
            }
            @policies_manager.process_policy_json(enablements, policies_json)
            @assert_all_policies_enabled.call(@policies_manager.policies)
          end
        end
      end
    end
  end
end
