require 'spec_helper'

module TCellAgent
  module Policies
    describe HeadersPolicy do
      describe '#get_headers' do
        context 'with enabled policy' do
          before(:each) do
            configuration = TCellAgent::Tests::ConfigurationBuilder.new.build
            @native_agent = TCellAgent::Rust::NativeAgent.create_agent(
              configuration
            )
            @tcell_context = TCellAgent::Tests::TCellContextBuilder.new.update_attribute(
              'session_id', 'session-id'
            ).update_attribute(
              'route_id', 'route-id'
            ).build

            enablements = @native_agent.update_policies(
              {
                'secure-headers' => {
                  'version' => 1,
                  'policy_id' => 'xyzd',
                  'headers' => [
                    {
                      'name' => 'X-Content-Type-Options',
                      'value' => 'nosniff'
                    }
                  ]
                }
              }
            )['enablements']
            expect(enablements['headers']).to eq(true)

            @policy = HeadersPolicy.new(@native_agent, enablements)
            expect(@policy.enabled).to eq(true)
          end

          after(:each) do
            TCellAgent::Rust::NativeAgent.free_agent(@native_agent.agent_ptr)
          end

          it 'should return csp header' do
            expect(
              @policy.get_headers('text/html', @tcell_context)
            ).to eq(
              [{ 'name' => 'X-Content-Type-Options',
                 'value' => 'nosniff' }]
            )
          end

          it 'should not return csp header on json' do
            expect(
              @policy.get_headers('application/json', @tcell_context)
            ).to eq([])
          end
        end
      end
    end
  end
end
