require 'spec_helper'

module TCellAgent
  module Utils
    describe '.better_ip' do
      context 'with reverse_proxy off' do
        it 'returns null' do
          configuration = double('configuration')
          request = double('request', :ip => '127.0.0.0')

          expect(TCellAgent).to receive(:configuration).and_return(configuration)
          expect(configuration).to receive(:reverse_proxy).and_return(false)
          expect(Rails.reverse_proxy_header(request)).to eq(nil)
        end
      end

      context 'with reverse_proxy on' do
        context 'with empty reverse_proxy_ip_address_header' do
          it 'returns null' do
            configuration = double('configuration')
            request = double('request', :ip => '127.0.0.0')

            expect(TCellAgent).to receive(:configuration).and_return(configuration)
            expect(configuration).to receive(:reverse_proxy).and_return(true)
            expect(TCellAgent).to receive(:configuration).and_return(configuration)
            expect(configuration).to receive(:reverse_proxy_ip_address_header).and_return('')
            expect(Rails.reverse_proxy_header(request)).to eq(nil)
          end
        end

        context "with reverse_proxy_ip_address_header that doesn't exist" do
          it 'returns null' do
            configuration = double('configuration')
            request = double('request', :ip => '127.0.0.0', :env => {})
            env = double('env')

            expect(TCellAgent).to receive(:configuration).and_return(configuration)
            expect(configuration).to receive(:reverse_proxy).and_return(true)
            expect(TCellAgent).to receive(:configuration).and_return(configuration)
            expect(configuration).to receive(:reverse_proxy_ip_address_header).and_return(
              'weird-http-proxy-header'
            )
            expect(request).to receive(:env).and_return(env)
            expect(env).to receive(:[]).with('HTTP_WEIRD_HTTP_PROXY_HEADER').and_return(nil)
            expect(Rails.reverse_proxy_header(request)).to eq(nil)
          end
        end

        context 'with reverse_proxy_ip_address_header that exists' do
          it 'should return proxied ip' do
            configuration = double('configuration')
            request = double('request', :ip => '127.0.0.0')
            env = double('env')

            expect(TCellAgent).to receive(:configuration).and_return(configuration)
            expect(configuration).to receive(:reverse_proxy).and_return(true)

            expect(TCellAgent).to receive(:configuration).and_return(configuration)
            expect(configuration).to receive(:reverse_proxy_ip_address_header).and_return(
              'X-Real-IP'
            )
            expect(request).to receive(:env).and_return(env)
            expect(env).to receive(:[]).with('HTTP_X_REAL_IP').and_return('192.168.99.100')
            expect(Rails.reverse_proxy_header(request)).to eq('192.168.99.100')
          end
        end
      end
    end
  end
end
