require 'spec_helper'

class WrapperClass
  include TCellAgent::CsrfExceptionReporter

  def request; end
end

module TCellAgent
  describe 'CsrfExceptionReporter' do
    before(:all) do
      @csrf_class = WrapperClass.new
    end

    context 'appfirewall_enabled=false' do
      it 'should not set csrf_exception_name' do
        appfirewall_policy = double('appfirewall_policy',
                                    :enabled => false)

        expect(TCellAgent).to receive(:policy).and_return(appfirewall_policy)
        expect(@csrf_class).to_not receive(:request)

        @csrf_class.handle_unverified_request
      end
    end

    context 'appfirewall_enabled=true and nil tcell_data' do
      it 'should not set csrf_exception_name' do
        appfirewall_policy = double('appfirewall_policy',
                                    :enabled => true)
        request = double('request',
                         :env => {})

        expect(TCellAgent).to receive(:policy).and_return(appfirewall_policy)
        expect(@csrf_class).to receive(:request).and_return(request)

        @csrf_class.handle_unverified_request
      end
    end

    context 'appfirewall_enabled=true and tcell_data present' do
      it 'should set csrf_exception_name' do
        tcell_data = TCellAgent::Instrumentation::TCellData.new
        expect(tcell_data.csrf_exception_name).to be(nil)

        appfirewall_policy = double('appfirewall_policy',
                                    :enabled => true)
        request = double('request',
                         :env => { TCellAgent::Instrumentation::TCELL_ID => tcell_data })

        expect(TCellAgent).to receive(:policy).and_return(appfirewall_policy)
        expect(@csrf_class).to receive(:request).and_return(request)

        @csrf_class.handle_unverified_request

        expect(tcell_data.csrf_exception_name).to eq('ActionController::InvalidAuthenticityToken')
      end
    end
  end
end
