require 'spec_helper'

module TCellAgent
  module Utils
    describe '.responses' do
      context '.empty_content?' do
        context 'with nil status code' do
          context 'with empty headers' do
            it 'should return false' do
              expect(Rails.empty_content?(nil, {})).to eq(nil)
            end
          end

          context 'with Content-Length header' do
            context 'that is zero' do
              it 'should return true' do
                expect(Rails.empty_content?(nil, { 'Content-Length' => 0 })).to eq(true)
              end
            end

            context 'that is non zero' do
              it 'should return false' do
                expect(Rails.empty_content?(nil, { 'Content-Length' => 1 })).to eq(false)
              end
            end
          end
        end

        context 'with a status code' do
          context 'that contains no content' do
            context 'with empty headers' do
              it 'should return true' do
                expect(Rails.empty_content?(204, {})).to eq(true)
              end
            end

            context 'with Content-Length header' do
              context 'that is zero' do
                it 'should return true' do
                  expect(Rails.empty_content?(204, { 'Content-Length' => 0 })).to eq(true)
                end
              end

              context 'that is non zero' do
                it 'should return true' do
                  expect(Rails.empty_content?(204, { 'Content-Length' => 1 })).to eq(true)
                end
              end
            end
          end

          context 'that contains content' do
            context 'with empty headers' do
              it 'should return false' do
                expect(Rails.empty_content?(200, {})).to eq(nil)
              end
            end

            context 'with Content-Length header' do
              context 'that is zero' do
                it 'should return true' do
                  expect(Rails.empty_content?(200, { 'Content-Length' => 0 })).to eq(true)
                end
              end

              context 'that is non zero' do
                it 'should return false' do
                  expect(Rails.empty_content?(200, { 'Content-Length' => 1 })).to eq(false)
                end
              end
            end
          end
        end
      end
    end
  end
end
