require 'spec_helper'

module TCellAgent
  module Instrumentation
    describe RouteId do
      tcell_context_key = TCellAgent::Instrumentation::TCELL_ID

      describe '.update_context' do
        context 'with nil route' do
          it 'should not set anything' do
            tcell_context = TCellData.new
            tcell_context.route_id = nil

            RouteId.update_context({ tcell_context_key => tcell_context }, {}, nil)

            expect(tcell_context.route_id).to eq(nil)
            expect(tcell_context.grape_mount_endpoint).to eq(nil)
            expect(tcell_context.path_parameters).to eq(nil)
          end
        end

        context 'with nil context' do
          it 'should not set anything ' do
            route = double('route')
            expect(route).to_not receive(:path)

            RouteId.update_context({}, {}, route)
          end
        end

        context 'with a regular route and parameters' do
          it 'should set the route id' do
            tcell_context = TCellData.new
            tcell_context.route_id = nil
            tcell_context.request_method = 'GET'

            route = double(
              'route',
              :path => double('path', :spec => '/some/regular/path')
            )

            expect(TCellAgent::Instrumentation).to receive(:grape_route?).with(route).and_return(false)

            RouteId.update_context({ tcell_context_key => tcell_context }, { :id => 1 }, route)

            expect(tcell_context.route_id).to eq(
              TCellAgent::SensorEvents::Util.calculate_route_id('GET', '/some/regular/path')
            )
            expect(tcell_context.grape_mount_endpoint).to eq(nil)
            expect(tcell_context.path_parameters).to eq({ :id => 1 })
          end
        end

        context 'with a grape route and parameters' do
          it 'should set the grape mount endpoint' do
            tcell_context = TCellData.new
            tcell_context.route_id = nil
            tcell_context.request_method = 'GET'

            route = double(
              'route',
              :path => double('path', :spec => '/grape_api')
            )

            expect(TCellAgent::Instrumentation).to receive(:grape_route?).with(route).and_return(true)

            RouteId.update_context({ tcell_context_key => tcell_context }, { :id => 1 }, route)

            expect(tcell_context.route_id).to eq(nil)
            expect(tcell_context.grape_mount_endpoint).to eq('/grape_api')
            expect(tcell_context.path_parameters).to eq({ :id => 1 })
          end
        end
      end
    end
  end
end
