require 'spec_helper'

module TCellAgent
  describe '.report_settings' do
    require 'tcell_agent/settings_reporter'

    it 'should not report all the settings' do
      logger = double('logger')
      configuration = double('configuration',
                             :enabled => true,
                             :should_instrument? => true,
                             :logger => logger,
                             :allow_payloads => true,
                             :reverse_proxy => true,
                             :reverse_proxy_ip_address_header => nil,
                             :log_filename => 'log-filename',
                             :agent_log_dir => 'agent-log-dir',
                             :agent_home_dir => 'agent-home-dir',
                             :agent_home_owner => nil,
                             :log_tag => nil,
                             :logging_options => {
                             },
                             :hmac_key => nil)

      expect(TCellAgent).to receive(:configuration).and_return(
        configuration
      ).at_least(:once)
      expect(TCellAgent).to receive(:logger).and_return(logger).at_least(:once)
      expect(Thread).to receive(:new).and_yield

      expect(logger).to receive(:debug).with(anything, anything).at_least(:once)
      expect(TCellAgent).to receive(:send_event).with(
        hash_including('event_type' => 'server_agent_packages')
      )

      expect(TCellAgent).to receive(:send_event).with(
        {
          'event_type' => 'app_config_setting',
          'package' => 'tcell',
          'section' => 'config',
          'name' => 'native_lib_loaded',
          'value' => 'true'
        }
      )

      TCellAgent.report_settings
    end
  end
end
