require 'spec_helper'

module TCellAgent
  describe MetaData do
    describe '#set_headers_dict' do
      it 'should set all headers that start with http and skip cookies' do
        method = remote_address = route_id = session_id = user_id = transaction_id = location = reverse_proxy_header_value = nil

        meta = MetaData.new(method, remote_address, route_id, session_id, user_id, transaction_id, location, reverse_proxy_header_value)
        meta.headers_dict = {
          'rack.version' => [1, 2],
          'REQUEST_METHOD' => 'POST',
          'SERVER_NAME' => 'www.example.com',
          'HTTP_USER_AGENT' => 'Mozilla',
          'HTTP_MY_CUSTOM_HTTP_HEADER' => 'my value'
        }

        expect(meta.flattened_headers_dict).to eq(
          {
            ['user-agent'] => 'Mozilla',
            ['my-custom-http-header'] => 'my value'
          }
        )
      end

      it 'should set all headers that start with http and include content_length and content_type' do
        method = remote_address = route_id = session_id = user_id = transaction_id = location = reverse_proxy_header_value = nil

        meta = MetaData.new(method, remote_address, route_id, session_id, user_id, transaction_id, location, reverse_proxy_header_value)
        meta.headers_dict = {
          'REQUEST_METHOD' => 'POST',
          'HTTP_VERSION' => 'HTTP/1.1',
          'HTTP_CONNECTION' => 'keep-alive',
          'CONTENT_LENGTH' => '85',
          'HTTP_CACHE_CONTROL' => 'max-age=0',
          'HTTP_ORIGIN' => 'http://192.168.99.100:3000',
          'HTTP_UPGRADE_INSECURE_REQUESTS' => '1',
          'HTTP_USER_AGENT' => 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_5)',
          'CONTENT_TYPE' => 'application/x-www-form-urlencoded',
          'HTTP_ACCEPT' => 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8',
          'HTTP_ACCEPT_ENCODING' => 'gzip, deflate',
          'HTTP_ACCEPT_LANGUAGE' => 'en-US,en;q=0.8',
          'HTTP_MY_CUSTOM_HTTP_HEADER' => 'my value'
        }

        expect(meta.flattened_headers_dict).to eq(
          {
            ['version'] => 'HTTP/1.1',
            ['connection'] => 'keep-alive',
            ['content-length'] => '85',
            ['cache-control'] => 'max-age=0',
            ['origin'] => 'http://192.168.99.100:3000',
            ['upgrade-insecure-requests'] => '1',
            ['user-agent'] => 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_5)',
            ['content-type'] => 'application/x-www-form-urlencoded',
            ['accept'] => 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8',
            ['accept-encoding'] => 'gzip, deflate',
            ['accept-language'] => 'en-US,en;q=0.8',
            ['my-custom-http-header'] => 'my value'
          }
        )
      end
    end

    describe '#body_params' do
      before(:each) do
        @meta_data = TCellAgent::MetaData.new(
          'get',
          'remote_address',
          'route_id',
          'session_id',
          'user_id',
          'transaction_id',
          'http://test.com',
          '0.0.0.0'
        )
      end

      context 'with application/json content type' do
      end
    end
  end
end
