require 'spec_helper'

module TCellAgent
  module Utils
    describe '.blank?' do
      context 'with nil' do
        it 'should return true' do
          expect(Strings.blank?(nil)).to be(true)
        end
      end

      context 'with empty string' do
        it 'should return true' do
          expect(Strings.blank?('')).to be(true)
        end
      end

      context 'with white space string' do
        it 'should return true' do
          expect(Strings.blank?("\t \r\n \s\s")).to be(true)
        end
      end

      context 'with a string containing non whitespace chars' do
        it 'should return false' do
          expect(Strings.blank?('A\t \r\n \s\s')).to be(false)
        end
      end
    end

    describe '.remove_trailing_slash' do
      context 'with nil' do
        it 'should return nil' do
          expect(Strings.remove_trailing_slash(nil)).to eq(nil)
        end
      end

      context 'with empty string' do
        it 'should return empty string' do
          expect(Strings.remove_trailing_slash('')).to eq('')
        end
      end

      context 'with / route' do
        it 'should return /' do
          expect(Strings.remove_trailing_slash('/')).to eq('/')
        end
      end

      context 'with no trailing slash' do
        it 'should return original string' do
          expect(Strings.remove_trailing_slash('/index')).to eq('/index')
        end
      end

      context 'with a trailing slash' do
        it 'should remove the trailing slash' do
          expect(Strings.remove_trailing_slash('/index')).to eq('/index')
        end
      end
    end

    describe '.java_hashcode' do
      context 'with some string' do
        it 'should equal the older java hash' do
          java = 312_563_920
          us = Strings.java_hashcode('The quick brown fox jumped over the lazy dogs.')
          expect(us).to eq(java)

          java = -1_225_848_487
          us = Strings.java_hashcode('I have a negative hash')
          expect(us).to eq(java)

          java = 628_018_387
          us = Strings.java_hashcode('你好世界')
          expect(us).to eq(java)
        end
      end
    end
  end
end
