require 'spec_helper'
require 'tcell_agent/config_initializer'

module TCellAgent
  module Tests
    class ConfigurationBuilder
      def initialize
        @configuration = TCellAgent::ConfigInitializer.new
        @configuration.fetch_policies_from_tcell = false
        @configuration.max_csp_header_bytes = nil
        @configuration.app_id = 'TestAppId-AppId'
        @configuration.api_key = 'TestAppId-AppId'
        @configuration.tcell_api_url = 'https://api.tcell-preview.io/agents/api/v1'
        @configuration.tcell_input_url = 'https://input.tcell-preview.io/api/v1'
        @configuration.hmac_key = nil
        @configuration.password_hmac_key = nil
        @configuration.allow_payloads = true
        @configuration.js_agent_api_base_url = @configuration.tcell_api_url
        @configuration.js_agent_url = 'https://jsagent.tcell.io/tcellagent.min.js'
        @configuration.agent_log_dir = 'tcell/logs'
        @configuration.logging_options = { :enabled => false }
        @configuration.host_identifier = 'python-test-suite'
        @configuration.reverse_proxy_ip_address_header = 'X-Forwarded-For'
        @configuration.enable_intercept_requests = true
        @configuration.enabled = true
      end

      def update_attribute(attribute, setting)
        @configuration.send("#{attribute}=", setting)

        self
      end

      def build
        @configuration
      end
    end

    class TCellContextBuilder
      def initialize
        @tcell_context = TCellAgent::Instrumentation::TCellData.new
        @tcell_context.session_id = 'session-id'
        @tcell_context.user_id = 'user-id'
        @tcell_context.user_agent = 'user-agent'
        @tcell_context.remote_address = '127.0.0.1'
        @tcell_context.transaction_id = nil
        @tcell_context.route_id = 'route-id'
        @tcell_context.path = '/some/path'
        @tcell_context.fullpath = '/some/path?hide-my-value=sensitive'
        @tcell_context.uri = 'http://domain.com/some/path?hide-my-value=sensitive'
        @tcell_context.patches_blocking_triggered = false
        @tcell_context.request_method = 'GET'
        @tcell_context.referrer = 'http://domain.com/home?_utm=some-value'
      end

      def update_attribute(attribute, setting)
        @tcell_context.send("#{attribute}=", setting)

        self
      end

      def build
        @tcell_context
      end
    end

    class MetaDataBuilder
      def initialize
        @meta_data = TCellAgent::MetaData.new(
          'GET',
          '127.0.0.1',
          'route-id',
          'session-id',
          'user-id',
          SecureRandom.uuid,
          'http://domain.com/some/path?hide-my-value=sensitive',
          '0.0.0.0'
        )

        @meta_data.path = '/some/path'
        @meta_data.request_content_bytes_len = 0
        @meta_data.response_content_bytes_len = 0
        @meta_data.response_code = 0
        @meta_data.user_agent = 'user-agent'
        @meta_data.get_dict = {}
        @meta_data.cookie_dict = {}
        @meta_data.headers_dict = {}
        @meta_data.post_dict = {}
        @meta_data.path_parameters = {}
        request = Rack::Request.new({ 'CONTENT_TYPE' => 'text/html', 'rack.input' => {} })
        @meta_data.set_parameter_dicts(request)
      end

      def update_attribute(attribute, setting)
        @meta_data.send("#{attribute}=", setting)

        self
      end

      def build
        @meta_data
      end
    end
  end
end
